@@ -2,7 +2,7 @@ package Plagger::Entry;
 use strict;
 
 use base qw( Plagger::Thing );
-__PACKAGE__->mk_accessors(qw( title author tags date link id summary body rate  icon meta));
+__PACKAGE__->mk_accessors(qw( title author tags date link id summary body rate  icon meta source ));
 
 use Digest::MD5;
 use DateTime::Format::Mail;
@@ -45,12 +45,6 @@ sub permalink {
     $self->{permalink} || $self->link;
 }
 
-sub clone {
-    my $self = shift;
-    my $clone = Storable::dclone($self);
-    $clone;
-}
-
 sub id_safe {
     my $self = shift;
     my $id   = $self->id || $self->link;
