@@ -65,9 +65,24 @@ sub sort_entries {
     # xxx reverse chron only, using Schwartzian transform
     my @entries = map { $_->[1] }
         sort { $b->[0] <=> $a->[0] }
-        map { [ $_->date || '', $_ ] } $self->entries;
+        map { [ $_->date || DateTime->from_epoch(epoch => 0), $_ ] } $self->entries;
 
     $self->{entries} = \@entries;
 }
 
+sub clear_entries {
+    my $self = shift;
+    $self->{entries} = [];
+}
+
+sub dedupe_entries {
+    my $self = shift;
+    my %seen;
+    my @entries;
+    for my $entry ($self->entries) {
+        push @entries, $entry if !$seen{$entry->id}++;
+    }
+    $self->{entries} = \@entries;
+}
+
 1;
